@@ -1,13 +1,13 @@
-use super::{INSView, INSUrl, NSUrl};
+use super::{INSUrl, INSView, NSUrl, NSWindow, INSPanel};
 use cocoa::foundation::NSInteger;
 use objc_foundation::{INSMutableArray, INSObject, INSString, NSMutableArray, NSString};
 use objc_id::Id;
 
-pub trait INSSavePanel: INSObject {
+pub trait INSSavePanel: INSPanel {
     fn save_panel() -> Id<Self> {
         unsafe {
             let ptr = msg_send![class!(NSSavePanel), savePanel];
-            Id::from_retained_ptr(ptr)
+            Id::from_ptr(ptr)
         }
     }
 
@@ -56,12 +56,11 @@ pub trait INSSavePanel: INSObject {
         unsafe { msg_send![self, setAccessoryViewDisclosed: flag] }
     }
 
-    fn run_modal(&self) -> Result<Id<NSUrl>, NSInteger> {
-        let response: NSInteger = unsafe { super::with_activation(|| msg_send![self, runModal]) };
-        match response {
+    fn run_modal(&self, owner: Option<Id<NSWindow>>) -> Result<Id<NSUrl>, NSInteger> {
+        match self.run_sheet_or_modal(owner) {
             1 => unsafe {
                 let urls = msg_send![self, URL];
-                Ok(Id::from_retained_ptr(urls))
+                Ok(Id::from_ptr(urls))
             },
             x => Err(x),
         }
@@ -70,4 +69,6 @@ pub trait INSSavePanel: INSObject {
 
 object_struct!(NSSavePanel);
 
+impl INSPanel for NSSavePanel {}
+
 impl INSSavePanel for NSSavePanel {}
